summaryrefslogtreecommitdiffstats
path: root/drivers/char/joystick/joy-thrustmaster.c
diff options
context:
space:
mode:
Diffstat (limited to 'drivers/char/joystick/joy-thrustmaster.c')
-rw-r--r--drivers/char/joystick/joy-thrustmaster.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/drivers/char/joystick/joy-thrustmaster.c b/drivers/char/joystick/joy-thrustmaster.c
index 3ea71416d..1e79b3281 100644
--- a/drivers/char/joystick/joy-thrustmaster.c
+++ b/drivers/char/joystick/joy-thrustmaster.c
@@ -25,7 +25,7 @@
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*
* Should you need to contact me, the author, you can do so either by
* e-mail - mail your message to <vojtech@ucw.cz>, or by paper mail:
* Vojtech Pavlik, Ucitelska 1576, Prague 8, 182 00 Czech Republic
*/
@@ -278,7 +278,7 @@ static struct js_port __init *js_tm_probe(int io, struct js_port *port)
if (info.mode >= JS_TM_MODE_MAX || !names[info.mode]) {
printk(KERN_WARNING "joy-thrustmaster: unknown device detected "
- "(io=%#x, id=%d), contact <vojtech@ucw.cz>\n",
+ "(io=%#x, id=%d), contact <vojtech@suse.cz>\n",
io, info.mode);
return port;
}
@@ -25,7 +25,7 @@
*
* Should you need to contact me, the author, you can do so either by
- * e-mail - mail your message to <vojtech@ucw.cz>, or by paper mail:
+ * e-mail - mail your message to <vojtech@suse.cz>, or by paper mail:
* Vojtech Pavlik, Ucitelska 1576, Prague 8, 182 00 Czech Republic
*/